WeaviateEx.Error.ClosedClientError exception (WeaviateEx v0.7.4)

Raised when operations are attempted on a closed client.

This error indicates that the client has been explicitly closed and can no longer be used for operations.

Example

client = Client.new(base_url: "http://localhost:8080")
Client.close(client)

# This will raise ClosedClientError
Client.request(client, :get, "/v1/meta", nil, [])

Summary

Types

t()

@type t() :: %WeaviateEx.Error.ClosedClientError{
  __exception__: true,
  closed_at: DateTime.t() | nil,
  message: String.t()
}