WeaviateEx.API.Vectorizers.Ref2VecCentroid (WeaviateEx v0.7.4)
View SourceRef2Vec-Centroid vectorizer configuration.
Calculates vectors based on the centroid of referenced objects' vectors. This is useful for creating aggregate vectors from cross-references.
Example
Ref2VecCentroid.new(
reference_properties: ["hasArticles", "hasComments"],
method: "mean"
)
Summary
Functions
Parse configuration from API response.
Create a new Ref2Vec-Centroid configuration.
Convert configuration to API format.
Returns the vectorizer name for the API.
Types
Functions
Parse configuration from API response.
Create a new Ref2Vec-Centroid configuration.
Options
:reference_properties- List of cross-reference property names to include:method- Centroid calculation method ("mean")
Convert configuration to API format.
@spec vectorizer_name() :: String.t()
Returns the vectorizer name for the API.